@@ -1,5 +1,3 @@
-##
-
 ##
 ## WWW::YouTube
 ##
@@ -17,7 +15,7 @@ require Date::Format;
 #my $VERSION="0.1";
 
 #For CVS , use following line
-our $VERSION = sprintf("%d.%04d", "Revision: 2006.0609" =~ /(\d+)\.(\d+)/);
+our $VERSION = sprintf("%d.%04d", "Revision: 2006.0615" =~ /(\d+)\.(\d+)/);
 
 BEGIN {
 
@@ -226,13 +224,25 @@ B<use lib ( $ENV{'HOME'} );>
 
 B<use WWW::YouTube::Com;> ## SEE DESCRIPTION
 
- Options;
-
-   --yt_*
+Options (--yt_* options);
 
 =head1 OPTIONS
 
---yt_*
+--yt_* options:
+
+opts_type_flag:
+
+   --yt_apache
+   --yt_mozilla
+
+opts_type_numeric:
+
+   NONE
+
+opts_type_string:
+
+   --yt_canon_tag=string
+   --yt_mozilla_bin=string
 
 =head1 DESCRIPTION
 
@@ -246,13 +256,17 @@ To use the YouTube Development Interface (YTDI) through your own YouTube Develop
 
 By the way, you need to go directly to YouTube at L<http://www.youtube.com> to do your registering, and you must think up a really good excuse for your desire to become a registered YouTube Developer.
 
-(Something like helping me to develop programs to protect the registered teenagers and the General Public, including children, from being exposed to too much adult content and other inappropriate material might work.)
+DON'T use something like helping me to develop programs to protect the registered teenagers and the General Public, including children, from being exposed to too much adult content and other inappropriate material.  It might not work to well, since on 06/14/2006, YouTube BLACKLISTED me for cleaning up the "hot babes," "foot fettish" and "bondage tickling" videos I found on YouTube.
 
-README at L<http://www.youtube.com/profile?user=ermeyers>
+README at L<http://www.youtube.com/profile?user=ermeyers>, if you can.  It has been 24 hours, and the YouTube Administrators still haven't told me why my account has been disabled.  YouTube, what is my "Terms of Use" offense to you?  I'll keep trying to get an answer, because as long as this guy L<http://www.youtube.com/watch?v=8uByGrzLLTs> or this girl L<http://www.youtube.com/watch?v=Bjtd9kmiyMI> are still YouTube "Gold Club" members, or the "Head" YouTube Administrators doing their daily "Self Worship" routine, things need to be corrected and all Children, Teenagers and the General Public, need to be protected continually with "Extreme Prejudice."
+
+Luke 9:5, "If people do not welcome you, shake the dust off your feet when you leave their town, as a testimony against them." --NIV
+
+Luke 10:11, "Even the dust of your town that sticks to our feet we wipe off against you. Yet be sure of this: The kingdom of God is near." --NIV
 
 Now, just because a public video on YouTube has been flagged as inappropriate material for the General Public, doesn't mean that a registered adult can't watch it.  Flagging keeps YouTube registered teenagers, and YouTube's unregistered General Public viewers, including children, from being able to view the contents of a public video identified as an inappropriate video, viewable by registered adults only, if they I<explicitly> choose to be viewing the public videos flagged as "inappropriate material," during their I<current> login session.
 
-You'll need to I<educate> yourself and I<experiment> with YouTube I<directly>, before going hog-wild with my WWW::YouTube applications, like I do, flagging videos.  "To protect children," that's my central theme and purpose for this B<EXPERIMENTAL> I<YouTube Development Interface> (YTDI) project, called B<WWW::YouTube>.
+You'll need to I<educate> yourself and I<experiment> with YouTube I<directly>, before going hog-wild with my WWW::YouTube applications, like I did, flagging videos.  "To protect children," that's my central theme and purpose for this B<EXPERIMENTAL> I<YouTube Development Interface> (YTDI) project, called B<WWW::YouTube>.
 
 What happens with the YTDI really depends on Who, What, When, Where and Which action it's activated.
 
@@ -260,7 +274,7 @@ And Why, and How?  What I<actually> happens, Why or How it I<happened>, really m
 
 Matthew 3:12, "His winnowing fork is in his hand, and he will clear his threshing floor, gathering his wheat into the barn and burning up the chaff with unquenchable fire." -- NIV
 
-README AGAIN at L<http://www.youtube.com/profile?user=ermeyers>
+README AGAIN at L<http://www.youtube.com/profile?user=ermeyers>, if you can.
 
 WWW::YouTube: "Keep it FUN, CLEAN and REAL," -- "to protect children!"
 
